
__version__ = "0.8.1"

__title__ = "jason-server"
__description__ = "JSON as REST API"
__url__ = "https://github.com/nekomamoushi/jason-server"

__author__ = "Jerome Pradier"
__author_email__ = "germione.grangere@gmail.com"

__license__ = "MIT"
